==> explainability-core-1.3.0.Final-sources.jar: org/kie/kogito/explainability/model/PartialDependenceGraph.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.explainability.model;

import java.util.List;

/**
 * A series of two dimensional points {@code (Feature:Value<?>, Output:Value<?>)} explaining partial dependency between
 * a {@link Feature} and an {@link Output} for a given model.
 */
public class PartialDependenceGraph {

    private final List<Value<?>> x;
    private final List<Value<?>> y;
    private final Feature feature;
    private final Output output;

    public PartialDependenceGraph(Feature feature, Output output, List<Value<?>> x, List<Value<?>> y) {
        this.feature = feature;
        this.output = output;
        this.x = x;
        this.y = y;
    }

    public Feature getFeature() {
        return feature;
    }

    public Output getOutput() {
        return output;
    }

    public List<Value<?>> getX() {
        return x;
    }

    public List<Value<?>> getY() {
        return y;
    }

    @Override
    public String toString() {
        return "PartialDependenceGraph{" +
                "x=" + x +
                ", y=" + y +
                ", feature=" + feature +
                ", output=" + output +
                '}';
    }
}

==> explainability-core-1.4.0.Final-sources.jar: org/kie/kogito/explainability/model/PartialDependenceGraph.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.explainability.model;

import java.util.List;

/**
 * A series of two dimensional points {@code (Feature:Value, Output:Value)} explaining partial dependency between
 * a {@link Feature} and an {@link Output} for a given model.
 */
public class PartialDependenceGraph {

    private final List<Value> x;
    private final List<Value> y;
    private final Feature feature;
    private final Output output;

    public PartialDependenceGraph(Feature feature, Output output, List<Value> x, List<Value> y) {
        this.feature = feature;
        this.output = output;
        this.x = x;
        this.y = y;
    }

    public Feature getFeature() {
        return feature;
    }

    public Output getOutput() {
        return output;
    }

    public List<Value> getX() {
        return x;
    }

    public List<Value> getY() {
        return y;
    }

    @Override
    public String toString() {
        return "PartialDependenceGraph{" +
                "x=" + x +
                ", y=" + y +
                ", feature=" + feature +
                ", output=" + output +
                '}';
    }
}
